authLoginCreate method

Future<TokenObtainResponse?> authLoginCreate(
  1. TokenObtainRequest tokenObtainRequest
)

Takes a set of user credentials and returns an access and refresh JSON web token pair to prove the authentication of those credentials.

Parameters:

Implementation

Future<TokenObtainResponse?> authLoginCreate(
  TokenObtainRequest tokenObtainRequest,
) async {
  final response = await authLoginCreateWithHttpInfo(
    tokenObtainRequest,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'TokenObtainResponse',
    ) as TokenObtainResponse;
  }
  return null;
}