authRefreshCreate method

Future<TokenRefreshResponse?> authRefreshCreate(
  1. TokenRefreshRequest tokenRefreshRequest
)

Takes a refresh type JSON web token and returns an access type JSON web token if the refresh token is valid.

Parameters:

Implementation

Future<TokenRefreshResponse?> authRefreshCreate(
  TokenRefreshRequest tokenRefreshRequest,
) async {
  final response = await authRefreshCreateWithHttpInfo(
    tokenRefreshRequest,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'TokenRefreshResponse',
    ) as TokenRefreshResponse;
  }
  return null;
}