preview property

bool? preview
getter/setter pair

True when model is in order and work is still in progress. False when order is completed.

Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.

Implementation

bool? preview;