modelsList method

Future<List<Model>?> modelsList({
  1. String? project,
  2. String? status,
})

Lists all models for all projects the user is a member of. Can be filtered by project.

Parameters:

  • String project:

  • String status: DRAFT=In development, READY=Modelling complete, ONLINE=Active use. * DRAFT - Draft * READY - Ready * ONLINE - Online

Implementation

Future<List<Model>?> modelsList({
  String? project,
  String? status,
}) async {
  final response = await modelsListWithHttpInfo(
    project: project,
    status: status,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    final responseBody = await _decodeBodyBytes(response);
    return (await apiClient.deserializeAsync(responseBody, 'List<Model>') as List)
        .cast<Model>()
        .toList(growable: false);
  }
  return null;
}