authGoogleCreateWithHttpInfo method

Future<Response> authGoogleCreateWithHttpInfo(
  1. GoogleIdToken googleIdToken
)

Takes a Google ID token and returns an access and refresh token for this API. If token is valid and user does not already exist, a new Yago user will be created.

Note: This method returns the HTTP Response.

Parameters:

Implementation

Future<Response> authGoogleCreateWithHttpInfo(
  GoogleIdToken googleIdToken,
) async {
  // ignore: prefer_const_declarations
  final path = r'/api/auth/google/';

  // ignore: prefer_final_locals
  Object? postBody = googleIdToken;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>['application/json'];

  return apiClient.invokeAPI(
    path,
    'POST',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}